<?php
/*-------------------------------------------------------+
| PHP-Fusion Content Management System
| Copyright (C) PHP-Fusion Inc
| https://www.php-fusion.co.uk/
+--------------------------------------------------------+
| Filename: classes/latestuser.php
| Author: karrak
+--------------------------------------------------------+
| This program is released as free software under the
| Affero GPL license. You can redistribute it and/or
| modify it under the terms of this license which you
| can read by viewing the included agpl.txt or online
| at www.gnu.org/licenses/agpl.html. Removal of this
| copyright header is strictly prohibited without
| written permission from the original author(s).
+--------------------------------------------------------*/
namespace PHPFusion\Luserpanel;

class LatestUser {
    private static $instance = NULL;
    private static $locale = [];

    public function __construct() {
        add_to_head("<link rel='stylesheet' href='".LTSU_PATH."latestuser.css' type='text/css' media='screen' />");
        include_once LTSU_PATH."templates/lastuser.tpl.php";
        self::$locale = fusion_get_locale("", LTSU_LOCALE);
    }

    public static function getInstance() {
        if (self::$instance === NULL) {
            self::$instance = new static();
        }
       return self::$instance;
    }

    public function StartLatestuser() {

        $info = [
            'openside' => "<i class='fa fa-legal fa-fw m-r-10'></i>".self::$locale['LTSU_00'],
	        'alluser'  => $this->alluser()
        ];
        LatestUserDisplay($info);
	}

    private function alluser() {
        $info = [];
        $result = dbquery( "SELECT user_id, user_name, user_status, user_avatar, user_lastvisit, user_level, user_language
            FROM ".DB_USERS."
            ".(iADMIN ? "" : (multilang_table("LTSU") ? "WHERE ".in_group('user_language', LANGUAGE) : ""))."
            ORDER BY user_lastvisit DESC
            LIMIT 0,10
        ");

        if (dbrows($result)) {
            while ($data = dbarray($result)) {
                $ustime = (time() - $data['user_lastvisit']);
                $class = ($ustime < 60 ? "tu-online" : ($ustime < 300 ? "tu-offline" : "tu-nouser"));
                $title = sprintf(self::$locale['LTSU_03'], $this->timelist($ustime), getuserlevel($data['user_level']), translate_lang_names($data['user_language']));

                $info[] = [
                    'avatar' => display_avatar($data, "50px", "", TRUE, "img-circle img-thumbnail ".$class." m-r-5"),
                    'profil' => profile_link($data['user_id'], ucfirst( $data['user_name'] ), $data['user_status'], "profile-link' title='".$title."")
                ];
            }
        }

        return $info;
    }

    private static function timelist($otime = FALSE) {

        $otime = (int)$otime;
        $second = 1;
        $minute = 60;
        $hour = 3600;
        $day = 86400;
        $wek = 604800;
        $month = $day * days_current_month();
        $year = ($day * ((date("L", $otime) > 0) ? 366 : 365));

        if ($otime < 1) {
            return self::$locale['LTSU_06'];
        }

        $timer = [
            $year   => self::$locale['LTSU_10'],
            $month  => self::$locale['LTSU_11'],
            $wek    => self::$locale['LTSU_12'],
            $day    => self::$locale['LTSU_13'],
            $hour   => self::$locale['LTSU_14'],
            $minute => self::$locale['LTSU_15'],
            $second => self::$locale['LTSU_16']
        ];
        foreach ($timer as $arr => $unit) {
            $calc = $otime / $arr;
            if ($calc >= 1) {
                $iH = floor($otime / 60 / 60) % 24;
                $iM = floor($otime / 60) % 60;
                $iS = floor($otime) % 60;
                if ($arr == 3600) {
                    return sprintf("%02d:%02d:%02d", $iH, $iM, $iS);
                } else if ($arr == 60) {
                    return sprintf("%02d:%02d", $iM, $iS);
                }
                $answer = round($calc);
                return sprintf($unit, $answer);
            }
        }
     }
}
